import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)
import login from '@/view/login'
import register from '@/view/register'
import home from '@/view/home'
import activity from '@/view/activity'
import cart from '@/view/cart'
import payInfo from '@/view/payInfo'
import userInfo from '@/view/userInfo'
import ticket from '@/view/ticket'

import layout from '@/layout'

export const constantRoutes = [
  {
    path: '',
    component: layout,
    name: 'layout',
    redirect: '/',
    children: [
      {
        path: '/',
        component: home,
        name: 'home',
        meta: { mustLogin: true }
      },
      {
        path: '/activity/:id/:code',
        component: activity,
        name: 'activity',
        meta: { mustLogin: true }
      },
      {
        path: '/pay/:id',
        component: payInfo,
        name: 'payInfo',
        meta: { mustLogin: true }
      },
    ],
    meta: {}
  },
  {
    path: '/cart',
    component: cart,
    name: 'cart',
    meta: { mustLogin: true, title: '購物籃' }
  },
  {
    path: '/ticket',
    component: ticket,
    name: 'ticket',
    meta: { mustLogin: true, title: '購買記錄' }
  },
  {
    path: '/user',
    component: userInfo,
    name: 'userInfo',
    meta: { mustLogin: true, title: '個人資料' }
  },
  {
    path: '/register',
    component: register,
    name: 'register',
    meta: { loginHidden: true }
  },
  {
    path: '/login',
    component: login,
    name: 'login',
    meta: { loginHidden: true }
  },
  { path: '*', redirect: '/', hidden: true }
]

const createRouter = () => new Router({
  mode: 'history', // require service support
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRoutes
})

const router = createRouter()


export default router