import axios from 'axios'
import store from '@/store/index'
import { getStorage, delStorage } from "@/utils/localStorage";
import router from '@/router'
import { Message } from 'element-ui'
// 创建axios实例
const service = axios.create({
  baseURL: process.env.VUE_APP_BASE_API, // api的base_url
  timeout: 200000, // 请求超时时间,
  headers: {
    'Content-Type': 'application/x-www-form-urlencoded',
  }
})
// request拦截器
service.interceptors.request.use(
  config => {
    let userToken = getStorage('userToken')
    if(!config.headers.authorization && userToken) {
      config.headers.authorization = 'Bearer ' + userToken
    }
    return config
  },
  error => {
    Promise.reject(error)
  }
)
// respone拦截器
service.interceptors.response.use(
  response => {
    if (response.status == 200) {
      let data = response.data || {}
      if (data.code) {
        if (data.code == 4000) {
          if (getStorage('userToken')) {
            delStorage('userToken')
            store.commit('SET_LOGIN', false)
            if (router.currentRoute.meta.mustLogin) {
              Message({
                message: '登入已過期',
                type: 'error',
                duration: 1500
              })
              router.replace('/login?rejectUrl=' + router.currentRoute.fullPath)
            }
          }
          return Promise.reject(response.data)
        }
        if (data.code == '200') {
          return data.token || data.pay_value || data.data || data.ordernum
        }
        Message({
          message: data.msg || data.MSG || data.code,
          type: 'error',
          duration: 1500
        })
        return Promise.reject(response.data)
      } else {
        return data.pageInfo || data.pay_value || data.data
      }
    } else {
      Message({
        message: response.data.message,
        type: 'error',
        duration: 2 * 1000
      })
      return Promise.reject(response.data)
    }
  },
  error => {
    return Promise.reject(error)
  }
)

export default service
